""" Init file for SRPPolarimetry

Context : SRP
Module  : Polarimetry
Version : 1.2.0
Author  : Stefano Covino
Date    : 18/11/2015
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino

Usage   : to be imported

History : (15/02/2012) First named version.
        : (10/11/2015) resid, centerGauss and getBackground added.
        : (13/11/2015) MinMax added.
        : (18/11/2015) centerMoment added.
"""


__all__ = ['centerGauss', 'centerMoment', 'Counts2Mag', 'Mag2Counts', 'getBackground',
            'MinMax', 'resid']



