""" Utility functions and classes for SRP

Context : SRP
Module  : Math
Version : 1.0.1
Author  : Stefano Covino
Date    : 22/03/2017
E-mail  : stefano.covino@brera.inaf.it
URL:    : http://www.merate.mi.astro.it/utenti/covino

Usage   : to be imported

Remarks :

History : (14/03/2017) First version.
        : (22/03/2017) Better version.
"""


def AngleRange (ang):
    return ang % 360.0


