""" 

Context : SRP
Module  : SRPDatabases
Version : 1.0.0
Author  : Stefano Covino
Date    : 21/02/2017
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (22/02/2017) First named version.
"""



__all__ = ['readMySQLTable', 'readPostgresTable']


