""" Init file for SRPPlot

Context : SRP
Module  : Plot
Version : 1.0.0
Author  : Stefano Covino
Date    : 12/08/2020
E-mail  : stefano.covino@inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino

Usage   : to be imported

History : (12/08/2020) First named version.
"""


__all__ = ['SetPlotPars', ]



